pecos.misc
==========

.. automodule:: pecos.misc



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.misc.commute
   pecos.misc.errors
   pecos.misc.gate_groups
   pecos.misc.stabilizer_funcs
   pecos.misc.std_output
   pecos.misc.symbol_library
   pecos.misc.threshold_curve
